annotation_functions: Field Value Annotation Functions

Description Arguments

Description

These functions add extra fields to a dataframe that annotate the field value meaning with what is provided in the UMLS Web Documentation.

Arguments

data

dataframe returned from a Metathesaurus query


patelm9/metaorite documentation built on Dec. 29, 2021, 4:37 a.m.